Draws the utility function and (if available) the elicited posterior over the risk parameter using base R graphics.
Usage
# S3 method for class 'risk_preference'
plot(x, ...)Draws the utility function and (if available) the elicited posterior over the risk parameter using base R graphics.
# S3 method for class 'risk_preference'
plot(x, ...)