Pre-computed performance matrices from a minimal-resolution run (DiscSteps = 3, MaxP = 3, seed = 1) of the Davis et al. (2019) System 1 social-ecological model (territorial use rights fishery). Used in unit tests to validate vira's EVPXI pipeline against the Davis formula.
Format
A list with elements:
- DiscSteps
Integer. Number of discrete values per parameter dimension (3).
- MaxP
Integer. Number of random draws of non-focal parameters (3).
- seed
Integer. Random seed used to generate the data (1).
- params
Named list with one entry per parameter (
I,q,r,C,H). Each entry contains:- PI
(DiscSteps^2 * MaxP) x 2matrix. Expected performance for each action under every joint parameter combination.- PI_X
DiscSteps^2 x 2matrix. Conditional mean performance per grid cell of the focal parameter (averaged over MaxP draws of non-focal parameters). This is the V matrix fed tovoi_problem().
Davis KJ, Chadès I, Rhodes JR, Bode M (2019). General rules for environmental management to prioritise social-ecological systems research based on a value of information approach. J Appl Ecol 56:2079–2090. doi:10.1111/1365-2664.13425 . Data: doi:10.5061/dryad.9nq5c8d